@@ -1,4 +1,4 @@
-from utility.config import Config
+from utility import config
 from utility.logger_handler import Logger
 
 class DB():
@@ -6,8 +6,8 @@ class DB():
 
     def __init__(self, name: str):
         self.name = name
-        self.db_uri = Config.db_uri
-        self.logger = Logger(Config.name).get_logger()
+        self.db_uri = config.get('DB_URI')
+        self.logger = Logger(config.get('NAME')).get_logger()
         self.get_connection()
 
     def get_connection(self):
